==> owncloud-9.0.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/encryption/l10n/pl.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Brakujące hasło klucza odzyskiwania",
    "Please repeat the recovery key password" : "Proszę powtórz nowe hasło klucza odzyskiwania",
    "Repeated recovery key password does not match the provided recovery key password" : "Hasła klucza odzyskiwania nie zgadzają się",
    "Recovery key successfully enabled" : "Klucz odzyskiwania włączony",
    "Could not enable recovery key. Please check your recovery key password!" : "Nie można włączyć klucza odzyskiwania. Proszę sprawdzić swoje hasło odzyskiwania!",
    "Recovery key successfully disabled" : "Klucz odzyskiwania wyłączony",
    "Could not disable recovery key. Please check your recovery key password!" : "Nie można wyłączyć klucza odzyskiwania. Proszę sprawdzić swoje hasło odzyskiwania!",
    "Please provide the old recovery password" : "Podaj stare hasło odzyskiwania",
    "Please provide a new recovery password" : "Podaj nowe hasło odzyskiwania",
    "Please repeat the new recovery password" : "Proszę powtórz nowe hasło odzyskiwania",
    "Password successfully changed." : "Zmiana hasła udana.",
    "Could not change the password. Maybe the old password was not correct." : "Nie można zmienić hasła. Może stare hasło nie było poprawne.",
    "Could not update the private key password." : "Nie można zmienić hasła klucza prywatnego.",
    "The old password was not correct, please try again." : "Stare hasło nie było poprawne. Spróbuj jeszcze raz.",
    "The current log-in password was not correct, please try again." : "Obecne hasło logowania nie było poprawne. Spróbuj ponownie.",
    "Private key password successfully updated." : "Pomyślnie zaktualizowano hasło klucza prywatnego.",
    "Invalid private key for Encryption App. Please update your private key password in your personal settings to recover access to your encrypted files." : "Klucz prywatny nie jest poprawny! Może Twoje hasło zostało zmienione z zewnątrz. Można zaktualizować hasło klucza prywatnego w ustawieniach osobistych w celu odzyskania dostępu do plików",
    "Encryption App is enabled but your keys are not initialized, please log-out and log-in again" : "Aplikacja szyfrująca jest aktywna, ale twoje klucze nie zostały zainicjowane, prosze wyloguj się i zaloguj ponownie.",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Nie można odszyfrować tego pliku, prawdopodobnie jest to plik udostępniony. Poproś właściciela pliku o ponowne udostępnianie pliku Tobie.",
    "The share will expire on %s." : "Ten zasób wygaśnie %s",
    "Cheers!" : "Pozdrawiam!",
    "Recovery key password" : "Hasło klucza odzyskiwania",
    "Change recovery key password:" : "Zmień hasło klucza odzyskiwania",
    "Change Password" : "Zmień hasło",
    "Your private key password no longer matches your log-in password." : "Hasło Twojego klucza prywatnego nie pasuje już do Twojego hasła logowania.",
    "Set your old private key password to your current log-in password:" : "Ustaw stare hasło klucza prywatnego na aktualne hasło logowania:",
    " If you don't remember your old password you can ask your administrator to recover your files." : "Jeśli nie pamiętasz swojego starego hasła, poproś swojego administratora, aby odzyskać pliki.",
    "Old log-in password" : "Stare hasło logowania",
    "Current log-in password" : "Bieżące hasło logowania",
    "Update Private Key Password" : "Aktualizacja hasła klucza prywatnego",
    "Enable password recovery:" : "Włącz hasło odzyskiwania:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Włączenie tej opcji umożliwia otrzymać dostęp do zaszyfrowanych plików w przypadku utraty hasła",
    "Enabled" : "Włączone",
    "Disabled" : "Wyłączone",
    "Could not enable the recovery key, please try again or contact your administrator" : "Nie można włączyć klucza odzyskiwania. Proszę spróbować ponownie lub skontakuj sie z administratorem",
    "Encryption App is enabled and ready" : "Aplikacja szyfrowania jest włączona i gotowa do pracy",
    "Missing parameters" : "Brakujące dane",
    "New recovery key password" : "Nowe hasło klucza odzyskiwania",
    "Old recovery key password" : "Stare hasło klucza odzyskiwania",
    "Recovery Key disabled" : "Klucz odzyskiwania wyłączony",
    "Recovery Key enabled" : "Klucz odzyskiwania włączony",
    "Repeat new recovery key password" : "Powtórz nowe hasło klucza odzyskiwania",
    "Repeat recovery key password" : "Powtórz hasło klucza odzyskiwania"
},
"nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> owncloud-9.1.3-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/encryption/l10n/pl.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Brakujące hasło klucza odzyskiwania",
    "Please repeat the recovery key password" : "Proszę powtórz nowe hasło klucza odzyskiwania",
    "Repeated recovery key password does not match the provided recovery key password" : "Hasła klucza odzyskiwania nie zgadzają się",
    "Recovery key successfully enabled" : "Klucz odzyskiwania włączony",
    "Could not enable recovery key. Please check your recovery key password!" : "Nie można włączyć klucza odzyskiwania. Proszę sprawdzić swoje hasło odzyskiwania!",
    "Recovery key successfully disabled" : "Klucz odzyskiwania wyłączony",
    "Could not disable recovery key. Please check your recovery key password!" : "Nie można wyłączyć klucza odzyskiwania. Proszę sprawdzić swoje hasło odzyskiwania!",
    "Missing parameters" : "Brakujące dane",
    "Please provide the old recovery password" : "Podaj stare hasło odzyskiwania",
    "Please provide a new recovery password" : "Podaj nowe hasło odzyskiwania",
    "Please repeat the new recovery password" : "Proszę powtórz nowe hasło odzyskiwania",
    "Password successfully changed." : "Zmiana hasła udana.",
    "Could not change the password. Maybe the old password was not correct." : "Nie można zmienić hasła. Może stare hasło nie było poprawne.",
    "Recovery Key disabled" : "Klucz odzyskiwania wyłączony",
    "Recovery Key enabled" : "Klucz odzyskiwania włączony",
    "Could not enable the recovery key, please try again or contact your administrator" : "Nie można włączyć klucza odzyskiwania. Proszę spróbować ponownie lub skontakuj sie z administratorem",
    "Could not update the private key password." : "Nie można zmienić hasła klucza prywatnego.",
    "The old password was not correct, please try again." : "Stare hasło nie było poprawne. Spróbuj jeszcze raz.",
    "The current log-in password was not correct, please try again." : "Obecne hasło logowania nie było poprawne. Spróbuj ponownie.",
    "Private key password successfully updated." : "Pomyślnie zaktualizowano hasło klucza prywatnego.",
    "Invalid private key for Encryption App. Please update your private key password in your personal settings to recover access to your encrypted files." : "Klucz prywatny nie jest poprawny! Może Twoje hasło zostało zmienione z zewnątrz. Można zaktualizować hasło klucza prywatnego w ustawieniach osobistych w celu odzyskania dostępu do plików",
    "Encryption App is enabled but your keys are not initialized, please log-out and log-in again" : "Aplikacja szyfrująca jest aktywna, ale twoje klucze nie zostały zainicjowane, prosze wyloguj się i zaloguj ponownie.",
    "Encryption App is enabled and ready" : "Aplikacja szyfrowania jest włączona i gotowa do pracy",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Nie można odszyfrować tego pliku, prawdopodobnie jest to plik udostępniony. Poproś właściciela pliku o ponowne udostępnianie pliku Tobie.",
    "The share will expire on %s." : "Ten zasób wygaśnie %s",
    "Cheers!" : "Dzięki!",
    "Enable recovery key" : "Włącz klucz odzyskiwania",
    "Disable recovery key" : "Wyłącz klucz odzyskiwania",
    "Recovery key password" : "Hasło klucza odzyskiwania",
    "Repeat recovery key password" : "Powtórz hasło klucza odzyskiwania",
    "Change recovery key password:" : "Zmień hasło klucza odzyskiwania",
    "Old recovery key password" : "Stare hasło klucza odzyskiwania",
    "New recovery key password" : "Nowe hasło klucza odzyskiwania",
    "Repeat new recovery key password" : "Powtórz nowe hasło klucza odzyskiwania",
    "Change Password" : "Zmień hasło",
    "Your private key password no longer matches your log-in password." : "Hasło Twojego klucza prywatnego nie pasuje już do Twojego hasła logowania.",
    "Set your old private key password to your current log-in password:" : "Ustaw stare hasło klucza prywatnego na aktualne hasło logowania:",
    " If you don't remember your old password you can ask your administrator to recover your files." : "Jeśli nie pamiętasz swojego starego hasła, poproś swojego administratora, aby odzyskać pliki.",
    "Old log-in password" : "Stare hasło logowania",
    "Current log-in password" : "Bieżące hasło logowania",
    "Update Private Key Password" : "Aktualizacja hasła klucza prywatnego",
    "Enable password recovery:" : "Włącz hasło odzyskiwania:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Włączenie tej opcji umożliwia otrzymać dostęp do zaszyfrowanych plików w przypadku utraty hasła",
    "Enabled" : "Włączone",
    "Disabled" : "Wyłączone"
},
"nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
